# harborapi.models.models

The canonical representation of the Harbor API models, after modifications have been made to rectify inconsistencies and errors in the official Swagger schema. To see the raw, unmodified models, see the [harborapi.models._models](./_models.md) module.

::: harborapi.models.models
    options:
        show_if_no_docstring: true
        show_source: true
        show_bases: true
        show_submodules: true
